@@ -8,13 +8,13 @@ library(magick)
 str(magick::magick_config())
 
 ## ---- eval = require(rsvg, quietly = TRUE)------------------------------------
-library(magick)
-tiger <- image_read_svg('http://jeroen.github.io/images/tiger.svg', width = 350)
-print(tiger)
+#  library(magick)
+#  tiger <- image_read_svg('http://jeroen.github.io/images/tiger.svg', width = 350)
+#  print(tiger)
 
 ## ---- eval = require(rsvg, quietly = TRUE)------------------------------------
-tiger_png <- image_convert(tiger, "png")
-image_info(tiger_png)
+#  tiger_png <- image_convert(tiger, "png")
+#  image_info(tiger_png)
 
 ## -----------------------------------------------------------------------------
 # Example image
@@ -158,7 +158,7 @@ image_animate(image_scale(img, "200x200"), fps = 1, dispose = "previous")
 
 ## -----------------------------------------------------------------------------
 newlogo <- image_scale(image_read("https://jeroen.github.io/images/Rlogo.png"))
-oldlogo <- image_scale(image_read("https://developer.r-project.org/Logo/Rlogo-3.png"))
+oldlogo <- image_scale(image_read("https://jeroen.github.io/images/Rlogo-old.png"))
 image_resize(c(oldlogo, newlogo), '200x150!') %>%
   image_background('white') %>%
   image_morph() %>%
@@ -235,17 +235,6 @@ library(grid)
 qplot(speed, dist, data = cars, geom = c("point", "smooth"))
 grid.raster(frink)
 
-## ---- fig.height=2------------------------------------------------------------
-tiff_file <- tempfile()
-image_write(frink, path = tiff_file, format = 'tiff')
-r <- raster::brick(tiff_file)
-raster::plotRGB(r)
-
-## ---- fig.height=2------------------------------------------------------------
-buf <- as.integer(frink[[1]])
-rr <- raster::brick(buf)
-raster::plotRGB(rr, asp = 1)
-
 ## ----eval=FALSE---------------------------------------------------------------
 #  install.packages("tesseract")
 
